app

package
v0.0.0-...-e51c130 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 21, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Boot

func Boot(ctx context.Context) (http.Handler, error)

Boot -

Types

This section is empty.

Directories

Path Synopsis
lib
blocklist
Package blocklist provides a blocklist based on ip and user-agent regexp.
Package blocklist provides a blocklist based on ip and user-agent regexp.
openmoji
Package openmoji provides image urls for emojis.
Package openmoji provides image urls for emojis.
totp
Package totp providers time-based one-time password management.
Package totp providers time-based one-time password management.

Jump to